@@ -131,6 +131,8 @@ test_logLik <- function(est) {
 }
 
 test_summary <- function(est, expected_no_lines) {
+  old_width <- options(width = 80)
+  on.exit(options(old_width), add = TRUE)
   no_lines <- length(capture.output(summary(est)))
   testthat::expect(expected_no_lines == no_lines, sprintf(
     "Expected %d output lines and got %d",
